Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(205)

Unified Diff: src/heap/heap.cc

Issue 1751043002: Speed up the LookupIterator (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Fix proxy + private symbols Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/api-natives.cc ('k') | src/heap/objects-visiting.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/heap/heap.cc
diff --git a/src/heap/heap.cc b/src/heap/heap.cc
index 3b5ee6e81b30516d5a29812269f8bb76a4ef3e45..0598afa94c5990d480aa5423101c1629f461293d 100644
--- a/src/heap/heap.cc
+++ b/src/heap/heap.cc
@@ -3574,11 +3574,12 @@ AllocationResult Heap::CopyJSObject(JSObject* source, AllocationSite* site) {
// Make the clone.
Map* map = source->map();
// We can only clone regexps, normal objects or arrays. Copying anything else
// will break invariants.
CHECK(map->instance_type() == JS_REGEXP_TYPE ||
map->instance_type() == JS_OBJECT_TYPE ||
- map->instance_type() == JS_ARRAY_TYPE);
+ map->instance_type() == JS_ARRAY_TYPE ||
+ map->instance_type() == JS_SPECIAL_API_OBJECT_TYPE);
int object_size = map->instance_size();
HeapObject* clone = nullptr;
« no previous file with comments | « src/api-natives.cc ('k') | src/heap/objects-visiting.cc » ('j') | no next file with comments »
@@ -3574,11 +3574,12 @@ AllocationResult Heap::CopyJSObject(JSObject* source, AllocationSite* site) {
// Make the clone.
Map* map = source->map();
- // We can only clone regexps, normal objects or arrays. Copying anything else
- // will break invariants.
+ // We can only clone regexps, normal objects, api objects or arrays. Copying
+ // anything else will break invariants.
CHECK(map->instance_type() == JS_REGEXP_TYPE ||
map->instance_type() == JS_OBJECT_TYPE ||

Powered by Google App Engine
This is Rietveld 408576698